@@ -1,4 +1,4 @@
-/* $Id$ */
+/* vi:set et ai sw=2 sts=2 ts=2: */
 /*-
  * Copyright (c) 2005-2006 Benedikt Meurer <benny@xfce.org>
  * Copyright (c) 2009 Jannis Pohlmann <jannis@xfce.org>
@@ -561,7 +561,7 @@ thunar_launcher_execute_files (ThunarLauncher *launcher,
     {
       working_directory = thunar_file_get_file (launcher->current_directory);
 
-      if (!thunar_file_execute (lp->data, working_directory, launcher->widget, NULL, &error))
+      if (!thunar_file_execute (lp->data, working_directory, launcher->widget, NULL, NULL, &error))
         {
           /* display an error message to the user */
           thunar_dialogs_show_error (launcher->widget, error, _("Failed to execute file \"%s\""), thunar_file_get_display_name (lp->data));
@@ -815,8 +815,9 @@ thunar_launcher_update_idle (gpointer data)
        ** - "Open", "Open in n New Windows" and "Open in n New Tabs" actions
        **/
 
-      /* Prepare "Open" label */
+      /* Prepare "Open" label and icon */
       gtk_action_set_label (launcher->action_open, _("_Open"));
+      gtk_action_set_stock_id (launcher->action_open, GTK_STOCK_OPEN);
 
       if (n_selected_files == n_directories && n_directories >= 1)
         {
@@ -928,6 +929,7 @@ thunar_launcher_update_idle (gpointer data)
           /* turn the "Open" action into "Execute" */
           g_object_set (G_OBJECT (launcher->action_open),
                         "label", _("_Execute"),
+                        "stock-id", GTK_STOCK_EXECUTE,
                         "tooltip", ngettext ("Execute the selected file", "Execute the selected files", n_selected_files),
                         NULL);
         }
@@ -945,6 +947,10 @@ thunar_launcher_update_idle (gpointer data)
           g_free (tooltip);
           g_free (label);
 
+          /* load default application icon */
+          gtk_action_set_stock_id (launcher->action_open, NULL);
+          gtk_action_set_gicon (launcher->action_open, g_app_info_get_icon (applications->data));
+
           /* remember the default application for the "Open" action */
           g_object_set_qdata_full (G_OBJECT (launcher->action_open), thunar_launcher_handler_quark, applications->data, g_object_unref);
 
